pytilities.testing — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »

# pytilities.testing

Test utilities

`pytilities.testing.` `get_recursive_package_test`(root, test_package)

  Get a test suite of all tests inside a package and its child packages

  Parameters:

  > root:: string
  >   absolute path of the top package’s directory of this python program
  > test_package:: string
  >   name of package to search in for tests, in dotted format, e.g. ‘project.test’

  See the wiki for a usage example.

  Returns ::unittest.TestSuite

`pytilities.testing.` `run`(test)

  Run test and print results to stderr

  Parameters:

  > test
  >   the TestCase to run

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »